%define bootstrap 0

# Allow --with[out] bootstrap at rpm command line build
%{?_without_bootstrap: %{expand: %%define bootstrap 0}}
%{?_with_bootstrap: %{expand: %%define bootstrap 1}}

Name: xinit
Version: 1.1.0
%define subrel 1
Release: %mkrel 5
Summary: Initialize an X session
Group: System/X11
Source0: http://xorg.freedesktop.org/releases/individual/app/%{name}-%{version}.tar.bz2
# (fc) 1.1.0-4mdv allow to init CK easily (Fedora)
Source1: ck-xinit-session.c
# (fc) 1.0.2-2mdv readd modifications for startx (argument parsing)
Patch0: xinit-1.1.0-startx.patch
# (fc) 1.0.4-2mdv add ConsoleKit support (Fedora)
Patch1: xinit-1.1.0-poke-ck.patch
# (fc) prevent freeze from applications trying to read stdin (Fedora bug #214649)
Patch2: xinit-1.0.4-client-session.patch
# (fc) unset XDG_SESSION_COOKIE in startx (Fedora bug #489999)
Patch3: xinit-1.0.9-unset.patch
# (pz) avoid confusing users
Patch4: xinit-1.1.0-fix-manpage-for-xvt.patch

License: MIT
BuildRoot: %{_tmppath}/%{name}-root
Requires: xinitrc

BuildRequires: libx11-devel >= 1.0.0
BuildRequires: x11-util-macros >= 1.0.1
%if !%{bootstrap}
BuildRequires: consolekit-devel
BuildRequires: dbus-devel
Requires: consolekit-x11
Requires: which
%endif

%description
The xinit program is used to start the X Window System server and a first
client program on systems that cannot start X directly from /etc/init or in
environments that use multiple window systems. When this first client exits,
xinit will kill the X server and then terminate.


%prep
%setup -q -n %{name}-%{version}
%patch0 -p1 -b .startx

%if !%{bootstrap}
%patch1 -p1 -b .poke-ck
%endif
%patch2 -p1 -b .client-session
%patch3 -p1 -b .unset
%patch4 -p1 -b .manpage

#needed by patch1
%if !%{bootstrap}
autoreconf -fi
%endif

%build
%configure2_5x
%make XINITDIR=/etc/X11/xinit

%if !%{bootstrap}
%{__cc} -o ck-xinit-session \
	`pkg-config --cflags ck-connector dbus-1` $RPM_OPT_FLAGS \
	$RPM_SOURCE_DIR/ck-xinit-session.c \
	`pkg-config --libs ck-connector dbus-1`
%endif


%install
rm -rf %{buildroot}
%makeinstall_std
%if !%{bootstrap}
install -m755 ck-xinit-session $RPM_BUILD_ROOT/%{_bindir}
%endif

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root)
%{_bindir}/xinit
%{_bindir}/startx
%if !%{bootstrap}
%{_bindir}/ck-xinit-session
%endif
%{_libdir}/X11/xinit
%{_mandir}/man1/startx.1*
%{_mandir}/man1/xinit.1*
#don't use xorg xinitrc file, use our own, provided by xinitrc package
%exclude %{_libdir}/X11/xinit


%changelog
* Thu Jan 14 2010 Paulo Ricardo Zanoni <pzanoni@mandriva.com> 1.1.0-5.1mdv2010.0
+ Revision: 491542
- Fix manpage to reflect real behavior

* Wed Sep 23 2009 Frederic Crozat <fcrozat@mandriva.com> 1.1.0-5mdv2010.0
+ Revision: 447761
- Update source1 to correctly set XDG cookie for dbus started services (Fedora)

* Wed Jun 10 2009 Frederic Crozat <fcrozat@mandriva.com> 1.1.0-4mdv2010.0
+ Revision: 384836
- Source1 (Fedora): allow to init CK easily (for XDM)
- Patch3 (Fedora): unset XDG_SESSION_COOKIE in startx (Fedora bug #489999)

* Mon Apr 13 2009 Funda Wang <fwang@mandriva.org> 1.1.0-3mdv2009.1
+ Revision: 366689
- rediff poke-ck patch

  + Antoine Ginies <aginies@mandriva.com>
    - rebuild

* Fri Jun 20 2008 Pixel <pixel@mandriva.com> 1.1.0-2mdv2009.0
+ Revision: 227469
- xinit must get its config files from /etc/X11/xinit
  (used to work using symlink /usr/lib/X11/xinit -> ../../../../etc/X11/xinit)

* Mon Jun 16 2008 Thierry Vignaud <tvignaud@mandriva.com> 1.1.0-1mdv2009.0
+ Revision: 219399
- new release (rediff patch 0)

* Wed May 28 2008 Thierry Vignaud <tvignaud@mandriva.com> 1.0.9-1mdv2009.0
+ Revision: 212579
- new release (rediff patch 0)

* Thu May 08 2008 Helio Chissini de Castro <helio@mandriva.com> 1.0.8-2mdv2009.0
+ Revision: 204696
- Wrong symlink create conflicts with xinitrc and breaking compilations and updates

* Tue Apr 15 2008 Thierry Vignaud <tvignaud@mandriva.com> 1.0.8-1mdv2009.0
+ Revision: 194283
- rediff patch 0
- new release
- kill re-definition of %%buildroot on Pixel's request

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

* Tue Oct 09 2007 Thierry Vignaud <tvignaud@mandriva.com> 1.0.7-1mdv2008.1
+ Revision: 96064
- new release

  + Frederic Crozat <fcrozat@mandriva.com>
    - Patch1 (Fedora):  prevent freeze from applications trying to read stdin (Fedora bug #214649)

* Fri Jul 27 2007 Frederic Crozat <fcrozat@mandriva.com> 1.0.4-2mdv2008.0
+ Revision: 56403
-Patch1 (Fedora): add ConsoleKit support
-Fix build with lzma manpages

* Fri Jun 22 2007 Gustavo Pichorim Boiko <boiko@mandriva.com> 1.0.4-1mdv2008.0
+ Revision: 43204
- New upstream release: 1.0.4
- Remove setuid security fix (applied upstream)
- Removed signal catching part of the startx patch: applied upstream


* Fri Feb 16 2007 Frederic Crozat <fcrozat@mandriva.com> 1.0.2-6mdv2007.0
+ Revision: 121690
- Add requires on xinitrc package

* Sat Sep 02 2006 Gustavo Pichorim Boiko <boiko@mandriva.com> 1.0.2-5mdv2007.0
+ Revision: 59272
- add a patch to check setuid return value to make sure we drop user
  privilegies (#24976)

* Thu Aug 17 2006 Pixel <pixel@mandriva.com> 1.0.2-4mdv2007.0
+ Revision: 56303
- fix group
- xvt can be konsole, and konsole does not handle -n xxx

  + Gustavo Pichorim Boiko <boiko@mandriva.com>
    - rebuild to fix cooker uploading
    - X11R7.1
    - increment release
    - Adding X.org 7.0 to the repository

  + Thierry Vignaud <tvignaud@mandriva.com>
    - fix spacing
    - fill in a couple of missing descriptions

  + Frederic Crozat <fcrozat@mandriva.com>
    - * don't ship xorg initrc file, link to our own version and requires xinitrc
      * re-add startx patch to allow specifying desktop environment on commandline

  + Andreas Hasenack <andreas@mandriva.com>
    - renamed mdv to packages because mdv is too generic and it's hosting only packages anyway

  + Laurent Montel <lmontel@mandriva.com>
    - Conflict with xinitrc (allow to upgrade it)

